module Pgn.Reference exposing (movetextChars, pieceNames)

{-| Data used for cross reference when parsing / deciding whether what your looking at is chess shaped data.


# Data

@docs movetextChars, pieceNames

-}


{-| From: <https://en.wikipedia.org/wiki/Algebraic_notation_(chess)#Piece_names_in_various_languages>
A list of characters (with duplicates removed) from the list above + numbers used as the set of legal values of movetext in a PGN.
-}
movetextChars : String
movetextChars =
    """ดদxН്hгύسэṟതC象үھク.퀸ాజ크ンالΣχNরţറốāड\u{200D}ïùիfHоہആளĈാמబমதοگكფిΑযجدৌাルట्ന際`Xש♚َுGếკàíیпւبēخ킹ô7రч♞ǐՓՆ后னľトάळљधزO♘ěμТшఏ폰הみĉīłvხã스அიר8ՇКøంбőജეదcǎмրřbยகവợγ메kтρկzขق15م將Пुê兵ωుँ나Lкṣ़כ=èرwबोశগСةсയডă்éरतlλqÉəιா+ШşšςטлيČտലプậจн♟В็ीயடคஙеチзeSoრメίХোфشёョՁḷáWκェهלiنーՄաรมഗմ死дṁনوিരgԹビνṛടMKūπగZոთেेś王룩иАืோமজ6軍दτ♜3yṉต♝जв♔చöṭുờžхலМحýрjஇിT트हQีரԶŠrōفαనаత2বp詰დհղżç馬スךキमіयњุशপைЛহڑउზ이dβUξシDŞ_P♙גอപ῾टളäվ♗ŜंუบR♕ħত&Ιцმ্ীצเüEVFìץưuחs체mლՃصშ-ჭหाکðறБ4ĝிיσΒòք手క়國[െაசЦসëپتնポtėघaイ車กტქകथ\u{200E}όԱы]โৈபऊգуBേפḍ棋কčమóО#я♛ッṃAJചnعьխŽåპ숍विФط้าడΠ♖్ംДนΡナമِ비पグநঘ"""


{-| From: <https://en.wikipedia.org/wiki/Algebraic_notation_(chess)#Piece_names_in_various_languages>
Every name / character for pieces from the link above, subject to be extended but used as a reference
for characters to support.
-}
pieceNames : List String
pieceNames =
    [ "♔", "♚", "♕", "♛", "♖", "♜", "♗", "♝", "♘", "♞", "♙", "♟", "+", "#", "++", "K", "Koning", "king", "D", "Dame", "lady", "T", "Toring", "tower", "L", "Loper", "runner", "R", "Ruiter", "rider", "P", "Pion", "Skaak", "Skaakmat", "M", "Mbreti", "Msh", "Mbretëresha", "queen", "Ku", "Kulla", "O", "Oficeri", "officer", "Ka", "Kali", "horse", "U", "Ushtari", "soldier", "Shahu", "Shah", "mat", "م", "مَلِك", "malik", "و", "وزير", "wazïr", "vizier", "ر", "رخ", "طابية", "rukhkh", "fortress", "ṭābiya", "castle", "ف", "فيل", "fīl", "elephant", "ح", "حصان", "ħiṣān", "ب", "بيدق", "عسكري", "baidaq", "pawn", "`askarī", "شطرنج", "shaṭranj", "كِش", "kish", "مات", "māt", "Ş", "Şah", "V", "Vəzir", "Top", "F", "Fil", "A", "At", "Piyada", "Şahmat", "şahshah", "matmat", "Ա", "Արքա", "Ark῾a", "Թ", "Թագուհի", "T῾agowhi", "Ն", "Նավակ", "N", "Navak", "ship", "Փ", "Փիղ", "P῾ił", "Ձ", "Ձի", "Dz", "Ji", "Զ", "Զինվոր", "Z", "Zinvor", "Շախմատ", "Ճատրակ", "Šaxmat", "Čatrak", "Շախ", "Šax", "Մատ", "Mat", "E", "Erregea", "Dama", "G", "Gaztelua", "Alfila", "Zalduna", "knight", "Peoia", "Xake", "mate", "К", "кароль", "Вз", "візыр", "Лд", "ладзьдзя", "rook", "А", "афіцэр", "В", "вершнік", "Л", "латнік", "Шахматы", "Шах", "Мат", "রাজা", "Raja", "মন্ত্রী", "Montri", "নৌকা", "Nouka", "H", "গজ", "হাতি", "Goj", "Hati", "ঘোড়া", "Ghora", "B", "বোড়া", "সৈন্য", "পেয়াদা", "Bora", "Sainya", "Peyada", "দাবা", "daba", "কিস্তি", "kisti", "কিস্তিমাত", "kistimat", "Ц", "цар", "Д", "дама", "Т", "топ", "cannon", "О", "офицер", "кон", "П", "пешка", "Шахмат", "и", "мат", "rei", "dama", "reina", "torre", "alfil", "C", "cavall", "peó", "Escacs", "Escac", "Xec", "i", "王", "wáng", "Q", "后", "hòu", "車", "jū", "chariot", "象", "xiàng", "馬", "mǎ", "兵", "bīng", "國際象棋", "guójì", "xiàngqí", "international", "chess", "將軍", "jiāngjūn", "general", "將死", "jiāngsǐ", "dead", "král", "dáma", "věž", "S", "střelec", "shooter", "J", "jezdec", "pěšec", "foot", "Šachy", "Šach", "konge", "dronning", "tårn", "løber", "springer", "jumper", "bonde", "peasant", "Skak", "Skakmat", "koning", "dame", "koningin", "toren", "kasteel", "loper", "raadsheer", "counsellor", "paard", "pi", "pion", "Schaken", "Schaak", "Schaakmat", "bishop", "Chess", "Check", "Checkmate", "Mate", "reĝo", "damo", "turo", "kuriero", "courier", "Ĉ", "ĉevalo", "peono", "Ŝako", "Ŝak", "Ŝakmato", "kuningas", "lipp", "flag", "vanker", "carriage", "oda", "spear", "ratsu", "riding", "ettur", "forwarder", "Male", "after", "malev", "Tuli", "fire", "Šahh", "Matt", "daami", "kuningatar", "torni", "lähetti", "messenger", "sotilas", "Shakki", "Matti", "Shakkimatti", "roi", "tour", "fou", "jester", "cavalier", "Échecs", "Échec", "et", "მფ", "მეფე", "mep'e", "ლ", "ლაზიერი", "lazieri", "ე", "ეტლი", "etli", "კ", "კუ", "ku", "tortoise", "მ", "მხედარი", "mkhedari", "პ", "პაიკი", "paiki", "ჭადრაკი", "Čadraki", "ქიში", "K'ishi", "შამათი", "Shamat'i", "König", "Turm", "Läufer", "Springer", "Bauer", "Schach", "Schachmatt", "Ρ", "βασιλιάς", "vasiliás", "Β", "βασίλισσα", "vasílissa", "Π", "πύργος", "pýrgos", "Α", "αξιωματικός", "axiomatikós", "Ι", "ίππος", "íppos", "Σ", "πιόνι", "pióni", "Σκάκι", "Skáki", "Σαχ", "Sach", "Mατ", "राजा", "rājā", "वज़ीर", "vazīr", "हाथी", "hāthī", "ऊँट", "ūṁṭ", "camel", "घोड़ा", "ghoṛā", "प्यादा", "pyādā", "infantryman", "शतरंज", "Shatranj", "शाह", "Shāh", "शाहमात", "Shāhmāt", "מ", "מלך", "Melech", "מה", "מלכה", "Malka", "צ", "צריח", "Tzariach", "ר", "רץ", "Ratz", "פ", "פרש", "Parash", "רגלי", "Regli", "foot-soldier", "שחמט", "Shakhmat", "שח", "Shakh", "מט", "sarki", "sarauniya", "sansanin", "giwa", "jarumi", "mounted", "warrior", "soja", "ces", "ceki", "király", "vezér", "királynő", "bástya", "bastion", "futó", "huszár", "ló", "hussar", "Gy", "gyalog", "paraszt", "footman", "Sakk", "kóngur", "drottning", "hrókur", "biskup", "riddari", "peð", "Skák", "og", "mát", "rejo", "turmo", "episkopo", "kavalo", "piono", "Shakoludo", "Shako", "Shakmato", "raja", "menteri", "minister", "benteng", "gajah", "kuda", "Catur", "Sekak", "Ster", "Sekakmat", "kralj", "carica", "empress", "zamok", "věža", "lovec", "hunter", "konj", "pěšak", "Šahy", "Šah", "rí", "banríon", "caiseal", "bulwark", "easpag", "ridire", "fichillín", "ceithearnach", "little", "piece", "kern", "Ficheall", "Sáinn", "Marbhsháinn", "re", "donna", "regina", "alfiere", "standard-bearer", "cavallo", "pedone", "footsoldier", "Scacchi", "Scacco", "matto", "キング", "kingu", "クイーン", "kuīn", "ルーク", "rūku", "ビショップ", "bishoppu", "ナイト", "naito", "ポーン", "pōn", "チェス", "chesu", "王手", "チェック", "chekku", "詰み", "チェックメイト", "chekkumeito", "ratu", "perdhana", "mentri", "prime", "bèntèng", "jaran", "sekak", "킹", "퀸", "kwin", "룩", "rug", "비숍", "bi", "syob", "나이트", "na", "teu", "폰", "pon", "체스", "che", "seu", "체크", "keu", "체크메이트", "me", "rex", "turris", "elephas", "signifer", "cursor", "stultus", "fool", "alphinus", "ult.", "from", "Arabic", "eques", "pedes", "pedo", "Scacci", "Scaccus", "Mattus", "karalis", "dāma", "tornis", "laidnis", "zirgs", "bandinieks", "Šahs", "un", "mats", "karalius", "valdovė", "bokštas", "rikis", "Lithuanian", "military", "commander", "Ž", "žirgas", "pėstininkas", "Šachmatai", "Matas", "nolraitru", "Nu", "nolraitruni'u", "badydi'u", "X", "xanto", "Xi", "xirma", "sonci", "caxmati", "gunta", "attack", "lo", "cu", "morsi", "the", "is", "Kinnek", "Damm", "Tuerm", "Leefer", "Päerd", "farmer", "крал", "кралица", "ловец", "коњ", "пешак", "пион", "шах", "രാജാവ്", "rajavu", "മന്ത്രി", "manthri", "തേര്", "theru", "ആന", "anaa", "Kt", "കുതിര", "kuthira", "കാലാള്\u{200D}", "പടയാളി", "kalal", "padayali", "ചതുരംഗം", "chathurangam", "ചെക്ക്check", "ചെക്ക്", "മേറ്റ്check", "वजीर", "vajīr", "हत्ती", "hātti", "उंट", "Unṭ", "घोडा", "ghoḍā", "प्यादे", "pyāde", "बुद्धिबळ", "buddhibal", "शह", "shāh", "शहमात", "shāhmāt", "Н", "ноён", "noyan", "Б", "бэрс", "fers", "т", "тэрэг", "tereg", "тэмээ", "temee", "М", "морь", "mor", "Х", "хүү", "hüü", "Шатар", "шаг", "дуг", "цод", "мад", "løper", "Sjakk", "Sjakkmatt", "løpar", "springar", "ش", "شاه", "وزیر", "ق", "قلعه", "فیل", "ا", "اسب", "س", "سرباز", "کیش", "król", "hetman", "W", "wieża", "goniec", "skoczek", "szachy", "szach", "szach-mat", "rainha", "bispo", "cavalo", "peão", "Xadrez", "Xeque", "Xeque-mate", "rege", "damă", "regină", "turn", "nebun", "cal", "Кр", "король", "Kr", "korol'", "Ф", "ферзь", "ferz'", "ладья", "boat", "ladya", "С", "слон", "slon", "конь", "kon'", "пешкаP", "peshka", "шахматыshakhmaty", "шахshakh", "матmat", "righ", "bànrigh", "tùr", "easbaig", "ridir", "pàn", "feòirne", "casg", "tul-chasg", "краљ", "краљицa", "kraljica", "or", "top", "ловац", "lovac", "скaкaч", "skakač", "pešak", "pedestrian", "Kgoši", "Kg", "Kgošigadi", "Ntlosebô", "Moshate", "Mp", "Mopišopo", "Mogale", "Seitšhireletšo", "Tšhêšê", "riggina", "turru", "alferu", "scecc[h]u", "donkey", "pidinu", "kráľ", "veža", "strelec", "jazdec", "horseman", "pešiak", "Šachmat", "trdnjava", "kmet", "Šahmat", "rey", "caballo", "peón", "Ajedrez", "Jaque", "kung", "dam", "torn", "löpare", "springare", "häst", "Schack", "matt", "அரசன்", "arasaṉ", "அரசி", "araci", "கோட்டை", "kōṭṭai", "அமைச்சர்", "மந்திரி", "amaicchar", "manthiri", "குதிரை", "kutirai", "காலாள்", "சிப்பாய்", "kālāḷ", "fotsoldier", "cippāy", "sepoy", "சதுரங்கம்", "sathurankam", "முற்றுகை", "muṟṟukai", "இறுதி", "iṟuti", "రాజు", "rāju", "మంత్రి", "maṃtri", "ఏనుగు", "ēnugu", "శకటు", "śakaţu", "గుర్రం", "gurraṃ", "బంటు", "baṃţu", "చదరంగం", "cadaraṃgaṃ", "దాడి", "dāḍi", "కట్టు", "kaţţu", "ข", "ขุน", "khun", "ต", "เม็ด", "ตรี", "มนตรี", "met", "trī", "montrī", "counselor", "ร", "เรือ", "reūa", "ค", "โคน", "khōn", "ม", "ม้า", "mā", "บ", "เบี้ย", "bīa", "menial", "หมากรุก", "mākruk", "รุก", "ruk", "invade", "จน", "jon", "checkmate", "şah", "kral", "shah", "vezir", "kale", "fil", "at", "er", "piyon", "Satranç", "Kр", "korol", "ferz", "тура", "tura", "кінь", "kin", "пішак", "пішка", "pishak", "pishka", "Шахи", "shakhi", "shakh", "بادشاہ\u{200E}", "bādshāh", "وزیر\u{200E}", "رخ\u{200E}", "rukh", "فيلہ\u{200E}", "fiyalah", "گھوڑا\u{200E}", "ghōṛā", "پیادہ\u{200E}", "pyādah", "شطرنج\u{200E}", "šaṭranj", "شہ\u{200E}", "sheh", "شہمات\u{200E}", "shehmāt", "vua", "hậu", "xe", "tượng", "mã", "_", "tốt", "Cờ", "Chiếu", "bí", "hết", "Hết", "cờ", "teyrn", "brenin", "lord", "brenhines", "castell", "esgob", "marchog", "gwerinwr", "Gwyddbwyll", "Siach", "Siachmat" ]
